# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class WorkflowDefinitionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_asset_type_assignment_rule(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Add asset type assignment rule.  # noqa: E501

        Adds an asset type assignment rule to the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_asset_type_assignment_rule(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param AddAssetTypeAssignmentRuleRequest add_asset_type_assignment_rule_request: The request describing assignment rule to be added.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AssetAssignmentRuleImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_asset_type_assignment_rule_with_http_info(workflow_definition_id, **kwargs)  # noqa: E501

    def add_asset_type_assignment_rule_with_http_info(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Add asset type assignment rule.  # noqa: E501

        Adds an asset type assignment rule to the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_asset_type_assignment_rule_with_http_info(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param AddAssetTypeAssignmentRuleRequest add_asset_type_assignment_rule_request: The request describing assignment rule to be added.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AssetAssignmentRuleImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id',
            'add_asset_type_assignment_rule_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_asset_type_assignment_rule" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `add_asset_type_assignment_rule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_asset_type_assignment_rule_request' in local_var_params:
            body_params = local_var_params['add_asset_type_assignment_rule_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/{workflowDefinitionId}/assetTypeAssignmentRules', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetAssignmentRuleImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_domain_type_assignment_rule(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Add domain type assignment rule.  # noqa: E501

        Adds a domain type assignment rule to the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_domain_type_assignment_rule(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param AddDomainTypeAssignmentRuleRequest add_domain_type_assignment_rule_request: The request describing assignment rule to be added.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AssetAssignmentRuleImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_domain_type_assignment_rule_with_http_info(workflow_definition_id, **kwargs)  # noqa: E501

    def add_domain_type_assignment_rule_with_http_info(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Add domain type assignment rule.  # noqa: E501

        Adds a domain type assignment rule to the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_domain_type_assignment_rule_with_http_info(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param AddDomainTypeAssignmentRuleRequest add_domain_type_assignment_rule_request: The request describing assignment rule to be added.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AssetAssignmentRuleImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id',
            'add_domain_type_assignment_rule_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_domain_type_assignment_rule" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `add_domain_type_assignment_rule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_domain_type_assignment_rule_request' in local_var_params:
            body_params = local_var_params['add_domain_type_assignment_rule_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/{workflowDefinitionId}/domainTypeAssignmentRules', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetAssignmentRuleImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_asset_type_assignment_rule(self, workflow_definition_id, rule_id, **kwargs):  # noqa: E501
        """Change asset type assignment rule.  # noqa: E501

        Modifies the asset type assignment rule with the specified ID of the workflow definition with the specified ID.<p>Only properties that are specified in this request and have not <code>null</code> values are updated.<p>All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_asset_type_assignment_rule(workflow_definition_id, rule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param str rule_id: The ID of the assignment rule to be changed. (required)
        :param ChangeAssetTypeAssignmentRuleRequest change_asset_type_assignment_rule_request: Parameters for the assignment rule to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AssetAssignmentRuleImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_asset_type_assignment_rule_with_http_info(workflow_definition_id, rule_id, **kwargs)  # noqa: E501

    def change_asset_type_assignment_rule_with_http_info(self, workflow_definition_id, rule_id, **kwargs):  # noqa: E501
        """Change asset type assignment rule.  # noqa: E501

        Modifies the asset type assignment rule with the specified ID of the workflow definition with the specified ID.<p>Only properties that are specified in this request and have not <code>null</code> values are updated.<p>All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_asset_type_assignment_rule_with_http_info(workflow_definition_id, rule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param str rule_id: The ID of the assignment rule to be changed. (required)
        :param ChangeAssetTypeAssignmentRuleRequest change_asset_type_assignment_rule_request: Parameters for the assignment rule to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AssetAssignmentRuleImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id',
            'rule_id',
            'change_asset_type_assignment_rule_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_asset_type_assignment_rule" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `change_asset_type_assignment_rule`")  # noqa: E501
        # verify the required parameter 'rule_id' is set
        if self.api_client.client_side_validation and ('rule_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['rule_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rule_id` when calling `change_asset_type_assignment_rule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501
        if 'rule_id' in local_var_params:
            path_params['ruleId'] = local_var_params['rule_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_asset_type_assignment_rule_request' in local_var_params:
            body_params = local_var_params['change_asset_type_assignment_rule_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/{workflowDefinitionId}/assetTypeAssignmentRules/{ruleId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetAssignmentRuleImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_domain_type_assignment_rule(self, workflow_definition_id, rule_id, **kwargs):  # noqa: E501
        """Change domain type assignment rule.  # noqa: E501

        Modifies the domain type assignment rule with the specified ID of the workflow definition with the specified ID.<p>Only properties that are specified in this request and have not <code>null</code> values are updated.<p>All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_domain_type_assignment_rule(workflow_definition_id, rule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param str rule_id: The ID of the assignment rule to be changed. (required)
        :param ChangeDomainTypeAssignmentRuleRequest change_domain_type_assignment_rule_request: Parameters for the assignment rule to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AssetAssignmentRuleImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_domain_type_assignment_rule_with_http_info(workflow_definition_id, rule_id, **kwargs)  # noqa: E501

    def change_domain_type_assignment_rule_with_http_info(self, workflow_definition_id, rule_id, **kwargs):  # noqa: E501
        """Change domain type assignment rule.  # noqa: E501

        Modifies the domain type assignment rule with the specified ID of the workflow definition with the specified ID.<p>Only properties that are specified in this request and have not <code>null</code> values are updated.<p>All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_domain_type_assignment_rule_with_http_info(workflow_definition_id, rule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param str rule_id: The ID of the assignment rule to be changed. (required)
        :param ChangeDomainTypeAssignmentRuleRequest change_domain_type_assignment_rule_request: Parameters for the assignment rule to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AssetAssignmentRuleImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id',
            'rule_id',
            'change_domain_type_assignment_rule_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_domain_type_assignment_rule" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `change_domain_type_assignment_rule`")  # noqa: E501
        # verify the required parameter 'rule_id' is set
        if self.api_client.client_side_validation and ('rule_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['rule_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rule_id` when calling `change_domain_type_assignment_rule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501
        if 'rule_id' in local_var_params:
            path_params['ruleId'] = local_var_params['rule_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_domain_type_assignment_rule_request' in local_var_params:
            body_params = local_var_params['change_domain_type_assignment_rule_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/{workflowDefinitionId}/domainTypeAssignmentRules/{ruleId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetAssignmentRuleImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_workflow_definition(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Change workflow definition.  # noqa: E501

        Modifies the workflow definition with the specified ID.<p>Only properties that are specified in this request and have not <code>null</code> values are updated.<p>All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_workflow_definition(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param ChangeWorkflowDefinitionRequest change_workflow_definition_request: Parameters for the workflow definition to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WorkflowDefinitionImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_workflow_definition_with_http_info(workflow_definition_id, **kwargs)  # noqa: E501

    def change_workflow_definition_with_http_info(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Change workflow definition.  # noqa: E501

        Modifies the workflow definition with the specified ID.<p>Only properties that are specified in this request and have not <code>null</code> values are updated.<p>All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_workflow_definition_with_http_info(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param ChangeWorkflowDefinitionRequest change_workflow_definition_request: Parameters for the workflow definition to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WorkflowDefinitionImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id',
            'change_workflow_definition_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_workflow_definition" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `change_workflow_definition`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_workflow_definition_request' in local_var_params:
            body_params = local_var_params['change_workflow_definition_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/{workflowDefinitionId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkflowDefinitionImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def deploy_workflow_definition(self, **kwargs):  # noqa: E501
        """Deploy workflow definition.  # noqa: E501

        Deploys workflow definition (the business process and resources) using the specified request.<p> The input stream can represent a single file(e.g: .bpmn20.xml or .bpmn) or an archive file (e.g: .zip or .bar). It is not allowed to deploy a resource containing more than one process definition.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.deploy_workflow_definition(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file file: The file with described workflow definition.
        :param str file_name: The name of the file.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WorkflowDefinitionImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.deploy_workflow_definition_with_http_info(**kwargs)  # noqa: E501

    def deploy_workflow_definition_with_http_info(self, **kwargs):  # noqa: E501
        """Deploy workflow definition.  # noqa: E501

        Deploys workflow definition (the business process and resources) using the specified request.<p> The input stream can represent a single file(e.g: .bpmn20.xml or .bpmn) or an archive file (e.g: .zip or .bar). It is not allowed to deploy a resource containing more than one process definition.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.deploy_workflow_definition_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file file: The file with described workflow definition.
        :param str file_name: The name of the file.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WorkflowDefinitionImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file',
            'file_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method deploy_workflow_definition" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in local_var_params:
            local_var_files['file'] = local_var_params['file']  # noqa: E501
        if 'file_name' in local_var_params:
            form_params.append(('fileName', local_var_params['file_name']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkflowDefinitionImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_workflow_definitions(self, **kwargs):  # noqa: E501
        """Find workflow definitions.  # noqa: E501

        Finds the workflow definitions matching the criteria described in the request object. By default, the result contains up to 1000 workflow definitions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_workflow_definitions(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param list[str] asset_id: The list of the IDs of business items (assets) for which the workflow definitions should be found.
        :param list[str] domain_id: The list of the IDs of business items (domains) for which the workflow definitions should be found.
        :param list[str] community_id: The list of the IDs of business items (communities) for which the workflow definitions should be found.
        :param bool enabled: Whether the found workflow definitions should be enabled.
        :param bool _global: Whether the found workflow definitions should be global.
        :param str name: The name (could be partial) of the workflow definition to search for.
        :param str sort_order: The sorting order.
        :param str description: The description (could be partial) of the workflow definition to search for.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WorkflowDefinitionPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_workflow_definitions_with_http_info(**kwargs)  # noqa: E501

    def find_workflow_definitions_with_http_info(self, **kwargs):  # noqa: E501
        """Find workflow definitions.  # noqa: E501

        Finds the workflow definitions matching the criteria described in the request object. By default, the result contains up to 1000 workflow definitions.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_workflow_definitions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param list[str] asset_id: The list of the IDs of business items (assets) for which the workflow definitions should be found.
        :param list[str] domain_id: The list of the IDs of business items (domains) for which the workflow definitions should be found.
        :param list[str] community_id: The list of the IDs of business items (communities) for which the workflow definitions should be found.
        :param bool enabled: Whether the found workflow definitions should be enabled.
        :param bool _global: Whether the found workflow definitions should be global.
        :param str name: The name (could be partial) of the workflow definition to search for.
        :param str sort_order: The sorting order.
        :param str description: The description (could be partial) of the workflow definition to search for.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WorkflowDefinitionPagedResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit',
            'count_limit',
            'asset_id',
            'domain_id',
            'community_id',
            'enabled',
            '_global',
            'name',
            'sort_order',
            'description'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_workflow_definitions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'count_limit' in local_var_params and local_var_params['count_limit'] is not None:  # noqa: E501
            query_params.append(('countLimit', local_var_params['count_limit']))  # noqa: E501
        if 'asset_id' in local_var_params and local_var_params['asset_id'] is not None:  # noqa: E501
            query_params.append(('assetId', local_var_params['asset_id']))  # noqa: E501
            collection_formats['assetId'] = 'multi'  # noqa: E501
        if 'domain_id' in local_var_params and local_var_params['domain_id'] is not None:  # noqa: E501
            query_params.append(('domainId', local_var_params['domain_id']))  # noqa: E501
            collection_formats['domainId'] = 'multi'  # noqa: E501
        if 'community_id' in local_var_params and local_var_params['community_id'] is not None:  # noqa: E501
            query_params.append(('communityId', local_var_params['community_id']))  # noqa: E501
            collection_formats['communityId'] = 'multi'  # noqa: E501
        if 'enabled' in local_var_params and local_var_params['enabled'] is not None:  # noqa: E501
            query_params.append(('enabled', local_var_params['enabled']))  # noqa: E501
        if '_global' in local_var_params and local_var_params['_global'] is not None:  # noqa: E501
            query_params.append(('global', local_var_params['_global']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('sortOrder', local_var_params['sort_order']))  # noqa: E501
        if 'description' in local_var_params and local_var_params['description'] is not None:  # noqa: E501
            query_params.append(('description', local_var_params['description']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkflowDefinitionPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_configuration_start_form_data(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Get configuration start form data.  # noqa: E501

        Returns the task configuration start form data of the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_configuration_start_form_data(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition that should be used for the form data retrieval. (required)
        :param str form_property_type: The form type to be returned.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StartFormDataImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_configuration_start_form_data_with_http_info(workflow_definition_id, **kwargs)  # noqa: E501

    def get_configuration_start_form_data_with_http_info(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Get configuration start form data.  # noqa: E501

        Returns the task configuration start form data of the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_configuration_start_form_data_with_http_info(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition that should be used for the form data retrieval. (required)
        :param str form_property_type: The form type to be returned.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StartFormDataImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id',
            'form_property_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_configuration_start_form_data" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `get_configuration_start_form_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501

        query_params = []
        if 'form_property_type' in local_var_params and local_var_params['form_property_type'] is not None:  # noqa: E501
            query_params.append(('formPropertyType', local_var_params['form_property_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/workflowDefinition/{workflowDefinitionId}/configurationStartFormData', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StartFormDataImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_possible_start_events(self, **kwargs):  # noqa: E501
        """Get all possible workflow start events  # noqa: E501

        Returns all possible workflow start events, including event name and description  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_possible_start_events(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[NamedDescribedWorkflowStartEventType]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_possible_start_events_with_http_info(**kwargs)  # noqa: E501

    def get_possible_start_events_with_http_info(self, **kwargs):  # noqa: E501
        """Get all possible workflow start events  # noqa: E501

        Returns all possible workflow start events, including event name and description  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_possible_start_events_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[NamedDescribedWorkflowStartEventType], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_possible_start_events" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/startEvents', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[NamedDescribedWorkflowStartEventType]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_start_form_data(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Get start form data.  # noqa: E501

        Returns the task start form data of the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_start_form_data(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition that should be used for the form data retrieval. (required)
        :param str form_property_type: The form type to be returned.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StartFormDataImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_start_form_data_with_http_info(workflow_definition_id, **kwargs)  # noqa: E501

    def get_start_form_data_with_http_info(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Get start form data.  # noqa: E501

        Returns the task start form data of the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_start_form_data_with_http_info(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition that should be used for the form data retrieval. (required)
        :param str form_property_type: The form type to be returned.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StartFormDataImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id',
            'form_property_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_start_form_data" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `get_start_form_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501

        query_params = []
        if 'form_property_type' in local_var_params and local_var_params['form_property_type'] is not None:  # noqa: E501
            query_params.append(('formPropertyType', local_var_params['form_property_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/workflowDefinition/{workflowDefinitionId}/startFormData', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StartFormDataImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workflow_definition(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Get workflow definition.  # noqa: E501

        Returns the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_definition(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WorkflowDefinitionImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_workflow_definition_with_http_info(workflow_definition_id, **kwargs)  # noqa: E501

    def get_workflow_definition_with_http_info(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Get workflow definition.  # noqa: E501

        Returns the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_definition_with_http_info(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WorkflowDefinitionImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_definition" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `get_workflow_definition`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/{workflowDefinitionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkflowDefinitionImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workflow_definition_by_process_id(self, process_id, **kwargs):  # noqa: E501
        """Get workflow definition.  # noqa: E501

        Returns the workflow definition with the specified process ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_definition_by_process_id(process_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str process_id: The process ID of the workflow definition. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WorkflowDefinitionImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_workflow_definition_by_process_id_with_http_info(process_id, **kwargs)  # noqa: E501

    def get_workflow_definition_by_process_id_with_http_info(self, process_id, **kwargs):  # noqa: E501
        """Get workflow definition.  # noqa: E501

        Returns the workflow definition with the specified process ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_definition_by_process_id_with_http_info(process_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str process_id: The process ID of the workflow definition. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WorkflowDefinitionImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'process_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_definition_by_process_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'process_id' is set
        if self.api_client.client_side_validation and ('process_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['process_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `process_id` when calling `get_workflow_definition_by_process_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'process_id' in local_var_params:
            path_params['processId'] = local_var_params['process_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/process/{processId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkflowDefinitionImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workflow_definition_diagram(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Get process diagram.  # noqa: E501

        Returns the process diagram of the workflow definition with the specified ID. The diagram input stream returned can be null as deployed workflow definitions without graphical notation included do not have a diagram.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_definition_diagram(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_workflow_definition_diagram_with_http_info(workflow_definition_id, **kwargs)  # noqa: E501

    def get_workflow_definition_diagram_with_http_info(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Get process diagram.  # noqa: E501

        Returns the process diagram of the workflow definition with the specified ID. The diagram input stream returned can be null as deployed workflow definitions without graphical notation included do not have a diagram.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_definition_diagram_with_http_info(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_definition_diagram" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `get_workflow_definition_diagram`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/{workflowDefinitionId}/diagram', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workflow_definition_xml(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Get XML of workflow definition.  # noqa: E501

        Returns the XML source of the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_definition_xml(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_workflow_definition_xml_with_http_info(workflow_definition_id, **kwargs)  # noqa: E501

    def get_workflow_definition_xml_with_http_info(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Get XML of workflow definition.  # noqa: E501

        Returns the XML source of the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_definition_xml_with_http_info(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_definition_xml" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `get_workflow_definition_xml`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/{workflowDefinitionId}/xml', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_assignment_rule(self, workflow_definition_id, rule_id, **kwargs):  # noqa: E501
        """Remove assignment rule.  # noqa: E501

        Removes the assignment rule with the specified ID from the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_assignment_rule(workflow_definition_id, rule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param str rule_id: The ID of the assignment rule. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_assignment_rule_with_http_info(workflow_definition_id, rule_id, **kwargs)  # noqa: E501

    def remove_assignment_rule_with_http_info(self, workflow_definition_id, rule_id, **kwargs):  # noqa: E501
        """Remove assignment rule.  # noqa: E501

        Removes the assignment rule with the specified ID from the workflow definition with the specified ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_assignment_rule_with_http_info(workflow_definition_id, rule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param str rule_id: The ID of the assignment rule. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id',
            'rule_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_assignment_rule" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `remove_assignment_rule`")  # noqa: E501
        # verify the required parameter 'rule_id' is set
        if self.api_client.client_side_validation and ('rule_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['rule_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rule_id` when calling `remove_assignment_rule`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501
        if 'rule_id' in local_var_params:
            path_params['ruleId'] = local_var_params['rule_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/{workflowDefinitionId}/assignmentRules/{ruleId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_workflow_definition(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Remove workflow definition.  # noqa: E501

        Removes the workflow definition with the specified ID. The workflow definition will be completely removed from the application, including any history.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_workflow_definition(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_workflow_definition_with_http_info(workflow_definition_id, **kwargs)  # noqa: E501

    def remove_workflow_definition_with_http_info(self, workflow_definition_id, **kwargs):  # noqa: E501
        """Remove workflow definition.  # noqa: E501

        Removes the workflow definition with the specified ID. The workflow definition will be completely removed from the application, including any history.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_workflow_definition_with_http_info(workflow_definition_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_definition_id: The ID of the workflow definition. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_definition_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_workflow_definition" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_definition_id' is set
        if self.api_client.client_side_validation and ('workflow_definition_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_definition_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_definition_id` when calling `remove_workflow_definition`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_definition_id' in local_var_params:
            path_params['workflowDefinitionId'] = local_var_params['workflow_definition_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/{workflowDefinitionId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_workflow_definitions_in_job(self, **kwargs):  # noqa: E501
        """Remove multiple workflow definitions.  # noqa: E501

        Removes multiple workflow definitions asynchronously. The workflow definition(s) will be completely removed from the application, including any history.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_workflow_definitions_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: The list of IDs of the workflow definitions to remove.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_workflow_definitions_in_job_with_http_info(**kwargs)  # noqa: E501

    def remove_workflow_definitions_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Remove multiple workflow definitions.  # noqa: E501

        Removes multiple workflow definitions asynchronously. The workflow definition(s) will be completely removed from the application, including any history.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_workflow_definitions_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: The list of IDs of the workflow definitions to remove.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Job, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_workflow_definitions_in_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowDefinitions/removalJobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class SymbolDataImpl(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'color': 'str',
        'symbol_type': 'str',
        'icon_code': 'str',
        'acronym_code': 'str'
    }

    attribute_map = {
        'color': 'color',
        'symbol_type': 'symbolType',
        'icon_code': 'iconCode',
        'acronym_code': 'acronymCode'
    }

    def __init__(self, color=None, symbol_type=None, icon_code=None, acronym_code=None, local_vars_configuration=None):  # noqa: E501
        """SymbolDataImpl - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._color = None
        self._symbol_type = None
        self._icon_code = None
        self._acronym_code = None
        self.discriminator = None

        if color is not None:
            self.color = color
        if symbol_type is not None:
            self.symbol_type = symbol_type
        if icon_code is not None:
            self.icon_code = icon_code
        if acronym_code is not None:
            self.acronym_code = acronym_code

    @property
    def color(self):
        """Gets the color of this SymbolDataImpl.  # noqa: E501


        :return: The color of this SymbolDataImpl.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this SymbolDataImpl.


        :param color: The color of this SymbolDataImpl.  # noqa: E501
        :type: str
        """

        self._color = color

    @property
    def symbol_type(self):
        """Gets the symbol_type of this SymbolDataImpl.  # noqa: E501


        :return: The symbol_type of this SymbolDataImpl.  # noqa: E501
        :rtype: str
        """
        return self._symbol_type

    @symbol_type.setter
    def symbol_type(self, symbol_type):
        """Sets the symbol_type of this SymbolDataImpl.


        :param symbol_type: The symbol_type of this SymbolDataImpl.  # noqa: E501
        :type: str
        """
        allowed_values = ["NONE", "ICON_CODE", "ACRONYM_CODE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and symbol_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `symbol_type` ({0}), must be one of {1}"  # noqa: E501
                .format(symbol_type, allowed_values)
            )

        self._symbol_type = symbol_type

    @property
    def icon_code(self):
        """Gets the icon_code of this SymbolDataImpl.  # noqa: E501


        :return: The icon_code of this SymbolDataImpl.  # noqa: E501
        :rtype: str
        """
        return self._icon_code

    @icon_code.setter
    def icon_code(self, icon_code):
        """Sets the icon_code of this SymbolDataImpl.


        :param icon_code: The icon_code of this SymbolDataImpl.  # noqa: E501
        :type: str
        """

        self._icon_code = icon_code

    @property
    def acronym_code(self):
        """Gets the acronym_code of this SymbolDataImpl.  # noqa: E501


        :return: The acronym_code of this SymbolDataImpl.  # noqa: E501
        :rtype: str
        """
        return self._acronym_code

    @acronym_code.setter
    def acronym_code(self, acronym_code):
        """Sets the acronym_code of this SymbolDataImpl.


        :param acronym_code: The acronym_code of this SymbolDataImpl.  # noqa: E501
        :type: str
        """

        self._acronym_code = acronym_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SymbolDataImpl):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SymbolDataImpl):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class WorkflowInstance(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_by': 'str',
        'created_on': 'int',
        'last_modified_by': 'str',
        'last_modified_on': 'int',
        'system': 'bool',
        'resource_type': 'str',
        'workflow_definition': 'WorkflowDefinitionReference',
        'sub_instances': 'list[WorkflowInstance]',
        'sub_process_instances_count': 'int',
        'parent_workflow_instance_id': 'str',
        'business_item': 'ResourceReference',
        'tasks': 'list[WorkflowTask]',
        'start_date': 'int',
        'ended': 'bool',
        'created_asset_id': 'str',
        'in_error': 'bool',
        'error_message': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_by': 'createdBy',
        'created_on': 'createdOn',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_on': 'lastModifiedOn',
        'system': 'system',
        'resource_type': 'resourceType',
        'workflow_definition': 'workflowDefinition',
        'sub_instances': 'subInstances',
        'sub_process_instances_count': 'subProcessInstancesCount',
        'parent_workflow_instance_id': 'parentWorkflowInstanceId',
        'business_item': 'businessItem',
        'tasks': 'tasks',
        'start_date': 'startDate',
        'ended': 'ended',
        'created_asset_id': 'createdAssetId',
        'in_error': 'inError',
        'error_message': 'errorMessage'
    }

    def __init__(self, id=None, created_by=None, created_on=None, last_modified_by=None, last_modified_on=None, system=None, resource_type=None, workflow_definition=None, sub_instances=None, sub_process_instances_count=None, parent_workflow_instance_id=None, business_item=None, tasks=None, start_date=None, ended=None, created_asset_id=None, in_error=None, error_message=None, local_vars_configuration=None):  # noqa: E501
        """WorkflowInstance - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_by = None
        self._created_on = None
        self._last_modified_by = None
        self._last_modified_on = None
        self._system = None
        self._resource_type = None
        self._workflow_definition = None
        self._sub_instances = None
        self._sub_process_instances_count = None
        self._parent_workflow_instance_id = None
        self._business_item = None
        self._tasks = None
        self._start_date = None
        self._ended = None
        self._created_asset_id = None
        self._in_error = None
        self._error_message = None
        self.discriminator = None

        self.id = id
        if created_by is not None:
            self.created_by = created_by
        if created_on is not None:
            self.created_on = created_on
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_on is not None:
            self.last_modified_on = last_modified_on
        if system is not None:
            self.system = system
        self.resource_type = resource_type
        if workflow_definition is not None:
            self.workflow_definition = workflow_definition
        if sub_instances is not None:
            self.sub_instances = sub_instances
        if sub_process_instances_count is not None:
            self.sub_process_instances_count = sub_process_instances_count
        if parent_workflow_instance_id is not None:
            self.parent_workflow_instance_id = parent_workflow_instance_id
        if business_item is not None:
            self.business_item = business_item
        if tasks is not None:
            self.tasks = tasks
        if start_date is not None:
            self.start_date = start_date
        if ended is not None:
            self.ended = ended
        if created_asset_id is not None:
            self.created_asset_id = created_asset_id
        if in_error is not None:
            self.in_error = in_error
        if error_message is not None:
            self.error_message = error_message

    @property
    def id(self):
        """Gets the id of this WorkflowInstance.  # noqa: E501

        The id of the represented object (entity).  # noqa: E501

        :return: The id of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WorkflowInstance.

        The id of the represented object (entity).  # noqa: E501

        :param id: The id of this WorkflowInstance.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_by(self):
        """Gets the created_by of this WorkflowInstance.  # noqa: E501

        The id of the user that created this resource.  # noqa: E501

        :return: The created_by of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this WorkflowInstance.

        The id of the user that created this resource.  # noqa: E501

        :param created_by: The created_by of this WorkflowInstance.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_on(self):
        """Gets the created_on of this WorkflowInstance.  # noqa: E501

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :return: The created_on of this WorkflowInstance.  # noqa: E501
        :rtype: int
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this WorkflowInstance.

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :param created_on: The created_on of this WorkflowInstance.  # noqa: E501
        :type: int
        """

        self._created_on = created_on

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this WorkflowInstance.  # noqa: E501

        The id of the user who modified this resource the last time.  # noqa: E501

        :return: The last_modified_by of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this WorkflowInstance.

        The id of the user who modified this resource the last time.  # noqa: E501

        :param last_modified_by: The last_modified_by of this WorkflowInstance.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_on(self):
        """Gets the last_modified_on of this WorkflowInstance.  # noqa: E501

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :return: The last_modified_on of this WorkflowInstance.  # noqa: E501
        :rtype: int
        """
        return self._last_modified_on

    @last_modified_on.setter
    def last_modified_on(self, last_modified_on):
        """Sets the last_modified_on of this WorkflowInstance.

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :param last_modified_on: The last_modified_on of this WorkflowInstance.  # noqa: E501
        :type: int
        """

        self._last_modified_on = last_modified_on

    @property
    def system(self):
        """Gets the system of this WorkflowInstance.  # noqa: E501

        Whether this is a system resource or not.  # noqa: E501

        :return: The system of this WorkflowInstance.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this WorkflowInstance.

        Whether this is a system resource or not.  # noqa: E501

        :param system: The system of this WorkflowInstance.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def resource_type(self):
        """Gets the resource_type of this WorkflowInstance.  # noqa: E501

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :return: The resource_type of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this WorkflowInstance.

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :param resource_type: The resource_type of this WorkflowInstance.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and resource_type is None:  # noqa: E501
            raise ValueError("Invalid value for `resource_type`, must not be `None`")  # noqa: E501
        allowed_values = ["View", "Asset", "Community", "Domain", "AssetType", "DomainType", "Status", "User", "ClassificationMatch", "UserGroup", "Attribute", "StringAttribute", "ScriptAttribute", "BooleanAttribute", "DateAttribute", "NumericAttribute", "SingleValueListAttribute", "MultiValueListAttribute", "Comment", "Attachment", "Responsibility", "Workflow", "Job", "Relation", "RelationType", "ComplexRelation", "ComplexRelationType", "ArticulationRule", "Assignment", "Scope", "RelationTrace", "ValidationRule", "DataQualityRule", "DataQualityMetric", "Address", "InstantMessagingAccount", "Email", "PhoneNumber", "Website", "Activity", "FormProperty", "WorkflowTask", "ActivityChange", "WorkflowInstance", "Role", "AttributeType", "BooleanAttributeType", "DateAttributeType", "DateTimeAttributeType", "MultiValueListAttributeType", "NumericAttributeType", "ScriptAttributeType", "SingleValueListAttributeType", "StringAttributeType", "ViewSharingRule", "ViewAssignmentRule", "JdbcDriverFile", "JdbcDriver", "JdbcIngestionProperties", "CsvIngestionProperties", "ExcelIngestionProperties", "ConnectionStringParameter", "AssignedCharacteristicType", "Notification", "Tag", "ComplexRelationLegType", "ComplexRelationAttributeType", "ComplexRelationLeg", "BaseDataType", "AdvancedDataType", "DiagramPicture", "DiagramPictureSharingRule", "DiagramPictureAssignmentRule", "Rating", "Classification", "PhysicalDataConnector", "Context"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and resource_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def workflow_definition(self):
        """Gets the workflow_definition of this WorkflowInstance.  # noqa: E501


        :return: The workflow_definition of this WorkflowInstance.  # noqa: E501
        :rtype: WorkflowDefinitionReference
        """
        return self._workflow_definition

    @workflow_definition.setter
    def workflow_definition(self, workflow_definition):
        """Sets the workflow_definition of this WorkflowInstance.


        :param workflow_definition: The workflow_definition of this WorkflowInstance.  # noqa: E501
        :type: WorkflowDefinitionReference
        """

        self._workflow_definition = workflow_definition

    @property
    def sub_instances(self):
        """Gets the sub_instances of this WorkflowInstance.  # noqa: E501

        The sub process instances of this instance.  # noqa: E501

        :return: The sub_instances of this WorkflowInstance.  # noqa: E501
        :rtype: list[WorkflowInstance]
        """
        return self._sub_instances

    @sub_instances.setter
    def sub_instances(self, sub_instances):
        """Sets the sub_instances of this WorkflowInstance.

        The sub process instances of this instance.  # noqa: E501

        :param sub_instances: The sub_instances of this WorkflowInstance.  # noqa: E501
        :type: list[WorkflowInstance]
        """

        self._sub_instances = sub_instances

    @property
    def sub_process_instances_count(self):
        """Gets the sub_process_instances_count of this WorkflowInstance.  # noqa: E501

        The count of sub process instances of this instance.  # noqa: E501

        :return: The sub_process_instances_count of this WorkflowInstance.  # noqa: E501
        :rtype: int
        """
        return self._sub_process_instances_count

    @sub_process_instances_count.setter
    def sub_process_instances_count(self, sub_process_instances_count):
        """Sets the sub_process_instances_count of this WorkflowInstance.

        The count of sub process instances of this instance.  # noqa: E501

        :param sub_process_instances_count: The sub_process_instances_count of this WorkflowInstance.  # noqa: E501
        :type: int
        """

        self._sub_process_instances_count = sub_process_instances_count

    @property
    def parent_workflow_instance_id(self):
        """Gets the parent_workflow_instance_id of this WorkflowInstance.  # noqa: E501

        The Id of the parent workflow instance.  # noqa: E501

        :return: The parent_workflow_instance_id of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._parent_workflow_instance_id

    @parent_workflow_instance_id.setter
    def parent_workflow_instance_id(self, parent_workflow_instance_id):
        """Sets the parent_workflow_instance_id of this WorkflowInstance.

        The Id of the parent workflow instance.  # noqa: E501

        :param parent_workflow_instance_id: The parent_workflow_instance_id of this WorkflowInstance.  # noqa: E501
        :type: str
        """

        self._parent_workflow_instance_id = parent_workflow_instance_id

    @property
    def business_item(self):
        """Gets the business_item of this WorkflowInstance.  # noqa: E501


        :return: The business_item of this WorkflowInstance.  # noqa: E501
        :rtype: ResourceReference
        """
        return self._business_item

    @business_item.setter
    def business_item(self, business_item):
        """Sets the business_item of this WorkflowInstance.


        :param business_item: The business_item of this WorkflowInstance.  # noqa: E501
        :type: ResourceReference
        """

        self._business_item = business_item

    @property
    def tasks(self):
        """Gets the tasks of this WorkflowInstance.  # noqa: E501

        The list of workflow tasks in this process instance.  # noqa: E501

        :return: The tasks of this WorkflowInstance.  # noqa: E501
        :rtype: list[WorkflowTask]
        """
        return self._tasks

    @tasks.setter
    def tasks(self, tasks):
        """Sets the tasks of this WorkflowInstance.

        The list of workflow tasks in this process instance.  # noqa: E501

        :param tasks: The tasks of this WorkflowInstance.  # noqa: E501
        :type: list[WorkflowTask]
        """

        self._tasks = tasks

    @property
    def start_date(self):
        """Gets the start_date of this WorkflowInstance.  # noqa: E501

        The start date of this process instance.  # noqa: E501

        :return: The start_date of this WorkflowInstance.  # noqa: E501
        :rtype: int
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this WorkflowInstance.

        The start date of this process instance.  # noqa: E501

        :param start_date: The start_date of this WorkflowInstance.  # noqa: E501
        :type: int
        """

        self._start_date = start_date

    @property
    def ended(self):
        """Gets the ended of this WorkflowInstance.  # noqa: E501

        Whether this process instance is already ended.  # noqa: E501

        :return: The ended of this WorkflowInstance.  # noqa: E501
        :rtype: bool
        """
        return self._ended

    @ended.setter
    def ended(self, ended):
        """Sets the ended of this WorkflowInstance.

        Whether this process instance is already ended.  # noqa: E501

        :param ended: The ended of this WorkflowInstance.  # noqa: E501
        :type: bool
        """

        self._ended = ended

    @property
    def created_asset_id(self):
        """Gets the created_asset_id of this WorkflowInstance.  # noqa: E501

        The optional identifier of the created asset if the process instance ended, created a term and it is configured for it.  # noqa: E501

        :return: The created_asset_id of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._created_asset_id

    @created_asset_id.setter
    def created_asset_id(self, created_asset_id):
        """Sets the created_asset_id of this WorkflowInstance.

        The optional identifier of the created asset if the process instance ended, created a term and it is configured for it.  # noqa: E501

        :param created_asset_id: The created_asset_id of this WorkflowInstance.  # noqa: E501
        :type: str
        """

        self._created_asset_id = created_asset_id

    @property
    def in_error(self):
        """Gets the in_error of this WorkflowInstance.  # noqa: E501

        Whether this process instance is in error. This means that there was a problem with a async continuation of the process instance.  # noqa: E501

        :return: The in_error of this WorkflowInstance.  # noqa: E501
        :rtype: bool
        """
        return self._in_error

    @in_error.setter
    def in_error(self, in_error):
        """Sets the in_error of this WorkflowInstance.

        Whether this process instance is in error. This means that there was a problem with a async continuation of the process instance.  # noqa: E501

        :param in_error: The in_error of this WorkflowInstance.  # noqa: E501
        :type: bool
        """

        self._in_error = in_error

    @property
    def error_message(self):
        """Gets the error_message of this WorkflowInstance.  # noqa: E501

        The optional error message of any error in a async continuation of this process instance. Only present if inError is true.  # noqa: E501

        :return: The error_message of this WorkflowInstance.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this WorkflowInstance.

        The optional error message of any error in a async continuation of this process instance. Only present if inError is true.  # noqa: E501

        :param error_message: The error_message of this WorkflowInstance.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowInstance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowInstance):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class ArticulationRuleRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'operation': 'str',
        'score': 'float',
        'status_id': 'str',
        'attribute_type_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'operation': 'operation',
        'score': 'score',
        'status_id': 'statusId',
        'attribute_type_id': 'attributeTypeId'
    }

    def __init__(self, id=None, operation=None, score=None, status_id=None, attribute_type_id=None, local_vars_configuration=None):  # noqa: E501
        """ArticulationRuleRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._operation = None
        self._score = None
        self._status_id = None
        self._attribute_type_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.operation = operation
        self.score = score
        if status_id is not None:
            self.status_id = status_id
        if attribute_type_id is not None:
            self.attribute_type_id = attribute_type_id

    @property
    def id(self):
        """Gets the id of this ArticulationRuleRequest.  # noqa: E501

        The ID of the articulation rule.  # noqa: E501

        :return: The id of this ArticulationRuleRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ArticulationRuleRequest.

        The ID of the articulation rule.  # noqa: E501

        :param id: The id of this ArticulationRuleRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def operation(self):
        """Gets the operation of this ArticulationRuleRequest.  # noqa: E501

        The <code>operation</code> ADD or SET.  # noqa: E501

        :return: The operation of this ArticulationRuleRequest.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this ArticulationRuleRequest.

        The <code>operation</code> ADD or SET.  # noqa: E501

        :param operation: The operation of this ArticulationRuleRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and operation is None:  # noqa: E501
            raise ValueError("Invalid value for `operation`, must not be `None`")  # noqa: E501
        allowed_values = ["ADD", "SET"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operation not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `operation` ({0}), must be one of {1}"  # noqa: E501
                .format(operation, allowed_values)
            )

        self._operation = operation

    @property
    def score(self):
        """Gets the score of this ArticulationRuleRequest.  # noqa: E501

        The articulation score (between 0 and 100).  # noqa: E501

        :return: The score of this ArticulationRuleRequest.  # noqa: E501
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this ArticulationRuleRequest.

        The articulation score (between 0 and 100).  # noqa: E501

        :param score: The score of this ArticulationRuleRequest.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and score is None:  # noqa: E501
            raise ValueError("Invalid value for `score`, must not be `None`")  # noqa: E501

        self._score = score

    @property
    def status_id(self):
        """Gets the status_id of this ArticulationRuleRequest.  # noqa: E501

        The ID of the status.  # noqa: E501

        :return: The status_id of this ArticulationRuleRequest.  # noqa: E501
        :rtype: str
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this ArticulationRuleRequest.

        The ID of the status.  # noqa: E501

        :param status_id: The status_id of this ArticulationRuleRequest.  # noqa: E501
        :type: str
        """

        self._status_id = status_id

    @property
    def attribute_type_id(self):
        """Gets the attribute_type_id of this ArticulationRuleRequest.  # noqa: E501

        The ID of the attribute type.  # noqa: E501

        :return: The attribute_type_id of this ArticulationRuleRequest.  # noqa: E501
        :rtype: str
        """
        return self._attribute_type_id

    @attribute_type_id.setter
    def attribute_type_id(self, attribute_type_id):
        """Sets the attribute_type_id of this ArticulationRuleRequest.

        The ID of the attribute type.  # noqa: E501

        :param attribute_type_id: The attribute_type_id of this ArticulationRuleRequest.  # noqa: E501
        :type: str
        """

        self._attribute_type_id = attribute_type_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArticulationRuleRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ArticulationRuleRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.mappings_api import MappingsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestMappingsApi(unittest.TestCase):
    """MappingsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.mappings_api.MappingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_mapping(self):
        """Test case for add_mapping

        Adds a new mapping.  # noqa: E501
        """
        pass

    def test_add_mappings(self):
        """Test case for add_mappings

        Adds new mappings.  # noqa: E501
        """
        pass

    def test_change_mapping(self):
        """Test case for change_mapping

        Changes the mapping identified by its id.  # noqa: E501
        """
        pass

    def test_change_mapping_by_external_entity(self):
        """Test case for change_mapping_by_external_entity

        Changes the mapping identified by its external ids.  # noqa: E501
        """
        pass

    def test_change_mapping_by_mapped_resource(self):
        """Test case for change_mapping_by_mapped_resource

        Changes the mapping identified by its external system id and mapped resource id.  # noqa: E501
        """
        pass

    def test_change_mappings(self):
        """Test case for change_mappings

        Changes multiple mappings identified by their ids.  # noqa: E501
        """
        pass

    def test_change_mappings_by_external_entities(self):
        """Test case for change_mappings_by_external_entities

        Changes the mappings identified by their external ids.  # noqa: E501
        """
        pass

    def test_change_mappings_by_mapped_resources(self):
        """Test case for change_mappings_by_mapped_resources

        Changes the mapping identified by their external system ids and mapped resource ids.  # noqa: E501
        """
        pass

    def test_find_mappings(self):
        """Test case for find_mappings

        Returns mappings matching the given search criteria.  # noqa: E501
        """
        pass

    def test_get_mapping(self):
        """Test case for get_mapping

        Returns a mapping identified by given id.  # noqa: E501
        """
        pass

    def test_get_mapping_by_external_entity(self):
        """Test case for get_mapping_by_external_entity

        Returns a mapping identified by its external ids.  # noqa: E501
        """
        pass

    def test_get_mapping_by_mapped_resource(self):
        """Test case for get_mapping_by_mapped_resource

        Returns a mapping identified by its external system id and mapped resource id.  # noqa: E501
        """
        pass

    def test_remove_mapping(self):
        """Test case for remove_mapping

        Removes the mapping identified by its id.  # noqa: E501
        """
        pass

    def test_remove_mapping_by_external_entity(self):
        """Test case for remove_mapping_by_external_entity

        Removes the mapping identified by its external ids.  # noqa: E501
        """
        pass

    def test_remove_mapping_by_mapped_resource(self):
        """Test case for remove_mapping_by_mapped_resource

        Removes the mapping identified by its external system id and mapped resource id.  # noqa: E501
        """
        pass

    def test_remove_mappings_by_external_system_in_job(self):
        """Test case for remove_mappings_by_external_system_in_job

        Removes all the mappings identified by given external system id.  # noqa: E501
        """
        pass

    def test_remove_mappings_in_job(self):
        """Test case for remove_mappings_in_job

        Removes multiple mappings in job.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.task_form_data import TaskFormData  # noqa: E501
from collibra_core.rest import ApiException

class TestTaskFormData(unittest.TestCase):
    """TaskFormData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TaskFormData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.task_form_data.TaskFormData()  # noqa: E501
        if include_optional :
            return TaskFormData(
                form_key = '0', 
                form_properties = [
                    collibra_core.models.form_property.FormProperty(
                        id = '0', 
                        name = '0', 
                        type = '0', 
                        value = '0', 
                        writable = True, 
                        required = True, 
                        enum_values = [
                            collibra_core.models.dropdown_value.DropdownValue(
                                parents = [
                                    '0'
                                    ], 
                                id_as_string = '0', 
                                id = '0', 
                                text = '0', )
                            ], 
                        check_buttons = [
                            collibra_core.models.option_value.OptionValue(
                                label = '0', 
                                value = '0', )
                            ], 
                        radio_buttons = [
                            collibra_core.models.option_value.OptionValue(
                                label = '0', 
                                value = '0', )
                            ], 
                        default_dropdown_values = [
                            collibra_core.models.dropdown_value.DropdownValue(
                                id_as_string = '0', 
                                id = '0', 
                                text = '0', )
                            ], 
                        proposed_dropdown_values = [
                            collibra_core.models.dropdown_value.DropdownValue(
                                id_as_string = '0', 
                                id = '0', 
                                text = '0', )
                            ], 
                        date_time_type = '0', 
                        multi_value = True, 
                        proposed_fixed = True, 
                        default_from_resource = True, 
                        multi_default_dropdown_values = {
                            'key' : [
                                collibra_core.models.dropdown_value.DropdownValue(
                                    id_as_string = '0', 
                                    id = '0', 
                                    text = '0', )
                                ]
                            }, 
                        multi_proposed_dropdown_values = {
                            'key' : [
                                collibra_core.models.dropdown_value.DropdownValue(
                                    id_as_string = '0', 
                                    id = '0', 
                                    text = '0', )
                                ]
                            }, 
                        asset_type = collibra_core.models.resource_reference.ResourceReference(
                            id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                            resource_type = 'Community', ), 
                        community_ids = [
                            '0'
                            ], 
                        domain_ids = [
                            '0'
                            ], 
                        status_ids = [
                            '0'
                            ], )
                    ], 
                task_id = '0', 
                contains_activity_stream = True, 
                subtitle = '0'
            )
        else :
            return TaskFormData(
        )

    def testTaskFormData(self):
        """Test TaskFormData"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class ActivityImpl(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user': 'UserReferenceImpl',
        'timestamp': 'int',
        'cause': 'str',
        'call_id': 'str',
        'call_count': 'int',
        'activity_type': 'str',
        'description': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user': 'user',
        'timestamp': 'timestamp',
        'cause': 'cause',
        'call_id': 'callId',
        'call_count': 'callCount',
        'activity_type': 'activityType',
        'description': 'description'
    }

    def __init__(self, id=None, user=None, timestamp=None, cause=None, call_id=None, call_count=None, activity_type=None, description=None, local_vars_configuration=None):  # noqa: E501
        """ActivityImpl - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user = None
        self._timestamp = None
        self._cause = None
        self._call_id = None
        self._call_count = None
        self._activity_type = None
        self._description = None
        self.discriminator = None

        self.id = id
        self.user = user
        self.timestamp = timestamp
        self.cause = cause
        self.call_id = call_id
        self.call_count = call_count
        self.activity_type = activity_type
        self.description = description

    @property
    def id(self):
        """Gets the id of this ActivityImpl.  # noqa: E501

        The id of the represented object (entity).  # noqa: E501

        :return: The id of this ActivityImpl.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ActivityImpl.

        The id of the represented object (entity).  # noqa: E501

        :param id: The id of this ActivityImpl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user(self):
        """Gets the user of this ActivityImpl.  # noqa: E501


        :return: The user of this ActivityImpl.  # noqa: E501
        :rtype: UserReferenceImpl
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this ActivityImpl.


        :param user: The user of this ActivityImpl.  # noqa: E501
        :type: UserReferenceImpl
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def timestamp(self):
        """Gets the timestamp of this ActivityImpl.  # noqa: E501

        The time when the activity happened. It is the timestamp (in UTC time standard).  # noqa: E501

        :return: The timestamp of this ActivityImpl.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ActivityImpl.

        The time when the activity happened. It is the timestamp (in UTC time standard).  # noqa: E501

        :param timestamp: The timestamp of this ActivityImpl.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    @property
    def cause(self):
        """Gets the cause of this ActivityImpl.  # noqa: E501

        The cause of the activity.  # noqa: E501

        :return: The cause of this ActivityImpl.  # noqa: E501
        :rtype: str
        """
        return self._cause

    @cause.setter
    def cause(self, cause):
        """Sets the cause of this ActivityImpl.

        The cause of the activity.  # noqa: E501

        :param cause: The cause of this ActivityImpl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and cause is None:  # noqa: E501
            raise ValueError("Invalid value for `cause`, must not be `None`")  # noqa: E501
        allowed_values = ["MANUAL", "IMPORT", "BULK_DELETE", "BULK_MOVE", "BULK_EDIT", "BULK_INSERT", "WORKFLOW"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and cause not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `cause` ({0}), must be one of {1}"  # noqa: E501
                .format(cause, allowed_values)
            )

        self._cause = cause

    @property
    def call_id(self):
        """Gets the call_id of this ActivityImpl.  # noqa: E501

        The ID of the call that resulted in an activity.  # noqa: E501

        :return: The call_id of this ActivityImpl.  # noqa: E501
        :rtype: str
        """
        return self._call_id

    @call_id.setter
    def call_id(self, call_id):
        """Sets the call_id of this ActivityImpl.

        The ID of the call that resulted in an activity.  # noqa: E501

        :param call_id: The call_id of this ActivityImpl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and call_id is None:  # noqa: E501
            raise ValueError("Invalid value for `call_id`, must not be `None`")  # noqa: E501

        self._call_id = call_id

    @property
    def call_count(self):
        """Gets the call_count of this ActivityImpl.  # noqa: E501

        The number of calls standing behind the activity.  # noqa: E501

        :return: The call_count of this ActivityImpl.  # noqa: E501
        :rtype: int
        """
        return self._call_count

    @call_count.setter
    def call_count(self, call_count):
        """Sets the call_count of this ActivityImpl.

        The number of calls standing behind the activity.  # noqa: E501

        :param call_count: The call_count of this ActivityImpl.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and call_count is None:  # noqa: E501
            raise ValueError("Invalid value for `call_count`, must not be `None`")  # noqa: E501

        self._call_count = call_count

    @property
    def activity_type(self):
        """Gets the activity_type of this ActivityImpl.  # noqa: E501

        The type of the activity, which could be ADD, UPDATE or DELETE.  # noqa: E501

        :return: The activity_type of this ActivityImpl.  # noqa: E501
        :rtype: str
        """
        return self._activity_type

    @activity_type.setter
    def activity_type(self, activity_type):
        """Sets the activity_type of this ActivityImpl.

        The type of the activity, which could be ADD, UPDATE or DELETE.  # noqa: E501

        :param activity_type: The activity_type of this ActivityImpl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and activity_type is None:  # noqa: E501
            raise ValueError("Invalid value for `activity_type`, must not be `None`")  # noqa: E501
        allowed_values = ["ADD", "UPDATE", "DELETE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and activity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `activity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(activity_type, allowed_values)
            )

        self._activity_type = activity_type

    @property
    def description(self):
        """Gets the description of this ActivityImpl.  # noqa: E501

        The description of the activity. It's the string in json format. It's exact content depends on activityType and on the type of the resource that was affected by the change. Possible fields are: <ul> <li> affected - always there, consists of id, type and name, it's the reference to the resource that was added, deleted or updated with the activity. </li> <li> new, old - for all activities of ActivityType.UPDATE, respectively new and old value of the field. It can be either the reference to another object (same as affected) or just a string (eg. name change). </li> <li> field - for ActivityType.UPDATE the name of the field that was changed, eg. status, name, target etc. </li> <li> role, people, resource - only for the responsibility activities, people means owner (user or group). </li> <li> source, target, role, coRole - only for relations (including complex relation legs). </li> <li> complexRelation, legs - only for complex relations, legs here stands for all the legs that the complex relation consists of. </li> <li> kind - only for attributes, it's attribute kind, eg. boolean, string, numeric etc. </li> <li> businessItem - only for workflows, reference to an object that is the business item for non-global workflows. </li> <li> attachmentFile - only for attachments, it's the name of the file that was attached. </li> <li> rating - only for ratings and reviews, contains a double representing the current rating </li> </ul>  # noqa: E501

        :return: The description of this ActivityImpl.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ActivityImpl.

        The description of the activity. It's the string in json format. It's exact content depends on activityType and on the type of the resource that was affected by the change. Possible fields are: <ul> <li> affected - always there, consists of id, type and name, it's the reference to the resource that was added, deleted or updated with the activity. </li> <li> new, old - for all activities of ActivityType.UPDATE, respectively new and old value of the field. It can be either the reference to another object (same as affected) or just a string (eg. name change). </li> <li> field - for ActivityType.UPDATE the name of the field that was changed, eg. status, name, target etc. </li> <li> role, people, resource - only for the responsibility activities, people means owner (user or group). </li> <li> source, target, role, coRole - only for relations (including complex relation legs). </li> <li> complexRelation, legs - only for complex relations, legs here stands for all the legs that the complex relation consists of. </li> <li> kind - only for attributes, it's attribute kind, eg. boolean, string, numeric etc. </li> <li> businessItem - only for workflows, reference to an object that is the business item for non-global workflows. </li> <li> attachmentFile - only for attachments, it's the name of the file that was attached. </li> <li> rating - only for ratings and reviews, contains a double representing the current rating </li> </ul>  # noqa: E501

        :param description: The description of this ActivityImpl.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityImpl):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ActivityImpl):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class ChangeUserRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'enabled': 'bool',
        'username': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'gender': 'str',
        'language': 'str',
        'license_type': 'str',
        'addresses': 'list[Address]',
        'phones': 'list[PhoneNumber]',
        'additional_email_addresses': 'list[Email]',
        'instant_messaging_accounts': 'list[InstantMessagingAccount]',
        'websites': 'list[Website]'
    }

    attribute_map = {
        'enabled': 'enabled',
        'username': 'username',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email',
        'gender': 'gender',
        'language': 'language',
        'license_type': 'licenseType',
        'addresses': 'addresses',
        'phones': 'phones',
        'additional_email_addresses': 'additionalEmailAddresses',
        'instant_messaging_accounts': 'instantMessagingAccounts',
        'websites': 'websites'
    }

    def __init__(self, enabled=None, username=None, first_name=None, last_name=None, email=None, gender=None, language=None, license_type=None, addresses=None, phones=None, additional_email_addresses=None, instant_messaging_accounts=None, websites=None, local_vars_configuration=None):  # noqa: E501
        """ChangeUserRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._enabled = None
        self._username = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._gender = None
        self._language = None
        self._license_type = None
        self._addresses = None
        self._phones = None
        self._additional_email_addresses = None
        self._instant_messaging_accounts = None
        self._websites = None
        self.discriminator = None

        if enabled is not None:
            self.enabled = enabled
        if username is not None:
            self.username = username
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email is not None:
            self.email = email
        if gender is not None:
            self.gender = gender
        if language is not None:
            self.language = language
        if license_type is not None:
            self.license_type = license_type
        if addresses is not None:
            self.addresses = addresses
        if phones is not None:
            self.phones = phones
        if additional_email_addresses is not None:
            self.additional_email_addresses = additional_email_addresses
        if instant_messaging_accounts is not None:
            self.instant_messaging_accounts = instant_messaging_accounts
        if websites is not None:
            self.websites = websites

    @property
    def enabled(self):
        """Gets the enabled of this ChangeUserRequest.  # noqa: E501

        The new enabled flag for the user  # noqa: E501

        :return: The enabled of this ChangeUserRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ChangeUserRequest.

        The new enabled flag for the user  # noqa: E501

        :param enabled: The enabled of this ChangeUserRequest.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def username(self):
        """Gets the username of this ChangeUserRequest.  # noqa: E501

        The new username for the user  # noqa: E501

        :return: The username of this ChangeUserRequest.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this ChangeUserRequest.

        The new username for the user  # noqa: E501

        :param username: The username of this ChangeUserRequest.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def first_name(self):
        """Gets the first_name of this ChangeUserRequest.  # noqa: E501

        The new first name for the user  # noqa: E501

        :return: The first_name of this ChangeUserRequest.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this ChangeUserRequest.

        The new first name for the user  # noqa: E501

        :param first_name: The first_name of this ChangeUserRequest.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this ChangeUserRequest.  # noqa: E501

        The new last name for the user  # noqa: E501

        :return: The last_name of this ChangeUserRequest.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this ChangeUserRequest.

        The new last name for the user  # noqa: E501

        :param last_name: The last_name of this ChangeUserRequest.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this ChangeUserRequest.  # noqa: E501

        The new e-mail address for the user  # noqa: E501

        :return: The email of this ChangeUserRequest.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ChangeUserRequest.

        The new e-mail address for the user  # noqa: E501

        :param email: The email of this ChangeUserRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 2147483647):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) < 1):
            raise ValueError("Invalid value for `email`, length must be greater than or equal to `1`")  # noqa: E501

        self._email = email

    @property
    def gender(self):
        """Gets the gender of this ChangeUserRequest.  # noqa: E501

        The new gender for the user  # noqa: E501

        :return: The gender of this ChangeUserRequest.  # noqa: E501
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this ChangeUserRequest.

        The new gender for the user  # noqa: E501

        :param gender: The gender of this ChangeUserRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MALE", "FEMALE", "UNKNOWN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and gender not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `gender` ({0}), must be one of {1}"  # noqa: E501
                .format(gender, allowed_values)
            )

        self._gender = gender

    @property
    def language(self):
        """Gets the language of this ChangeUserRequest.  # noqa: E501

        The new language for the user  # noqa: E501

        :return: The language of this ChangeUserRequest.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this ChangeUserRequest.

        The new language for the user  # noqa: E501

        :param language: The language of this ChangeUserRequest.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def license_type(self):
        """Gets the license_type of this ChangeUserRequest.  # noqa: E501

        The license type of the user. LicenseType will be removed in the future.  # noqa: E501

        :return: The license_type of this ChangeUserRequest.  # noqa: E501
        :rtype: str
        """
        return self._license_type

    @license_type.setter
    def license_type(self, license_type):
        """Sets the license_type of this ChangeUserRequest.

        The license type of the user. LicenseType will be removed in the future.  # noqa: E501

        :param license_type: The license_type of this ChangeUserRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["CONSUMER", "AUTHOR"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and license_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `license_type` ({0}), must be one of {1}"  # noqa: E501
                .format(license_type, allowed_values)
            )

        self._license_type = license_type

    @property
    def addresses(self):
        """Gets the addresses of this ChangeUserRequest.  # noqa: E501

        The postal addresses of the user  # noqa: E501

        :return: The addresses of this ChangeUserRequest.  # noqa: E501
        :rtype: list[Address]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """Sets the addresses of this ChangeUserRequest.

        The postal addresses of the user  # noqa: E501

        :param addresses: The addresses of this ChangeUserRequest.  # noqa: E501
        :type: list[Address]
        """

        self._addresses = addresses

    @property
    def phones(self):
        """Gets the phones of this ChangeUserRequest.  # noqa: E501

        The phone numbers of the user  # noqa: E501

        :return: The phones of this ChangeUserRequest.  # noqa: E501
        :rtype: list[PhoneNumber]
        """
        return self._phones

    @phones.setter
    def phones(self, phones):
        """Sets the phones of this ChangeUserRequest.

        The phone numbers of the user  # noqa: E501

        :param phones: The phones of this ChangeUserRequest.  # noqa: E501
        :type: list[PhoneNumber]
        """

        self._phones = phones

    @property
    def additional_email_addresses(self):
        """Gets the additional_email_addresses of this ChangeUserRequest.  # noqa: E501

        The additional e-mail addresses of the user  # noqa: E501

        :return: The additional_email_addresses of this ChangeUserRequest.  # noqa: E501
        :rtype: list[Email]
        """
        return self._additional_email_addresses

    @additional_email_addresses.setter
    def additional_email_addresses(self, additional_email_addresses):
        """Sets the additional_email_addresses of this ChangeUserRequest.

        The additional e-mail addresses of the user  # noqa: E501

        :param additional_email_addresses: The additional_email_addresses of this ChangeUserRequest.  # noqa: E501
        :type: list[Email]
        """

        self._additional_email_addresses = additional_email_addresses

    @property
    def instant_messaging_accounts(self):
        """Gets the instant_messaging_accounts of this ChangeUserRequest.  # noqa: E501

        The instant messaging accounts of the user  # noqa: E501

        :return: The instant_messaging_accounts of this ChangeUserRequest.  # noqa: E501
        :rtype: list[InstantMessagingAccount]
        """
        return self._instant_messaging_accounts

    @instant_messaging_accounts.setter
    def instant_messaging_accounts(self, instant_messaging_accounts):
        """Sets the instant_messaging_accounts of this ChangeUserRequest.

        The instant messaging accounts of the user  # noqa: E501

        :param instant_messaging_accounts: The instant_messaging_accounts of this ChangeUserRequest.  # noqa: E501
        :type: list[InstantMessagingAccount]
        """

        self._instant_messaging_accounts = instant_messaging_accounts

    @property
    def websites(self):
        """Gets the websites of this ChangeUserRequest.  # noqa: E501

        The websites of the user  # noqa: E501

        :return: The websites of this ChangeUserRequest.  # noqa: E501
        :rtype: list[Website]
        """
        return self._websites

    @websites.setter
    def websites(self, websites):
        """Sets the websites of this ChangeUserRequest.

        The websites of the user  # noqa: E501

        :param websites: The websites of this ChangeUserRequest.  # noqa: E501
        :type: list[Website]
        """

        self._websites = websites

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeUserRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChangeUserRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.statuses_api import StatusesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestStatusesApi(unittest.TestCase):
    """StatusesApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.statuses_api.StatusesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_status(self):
        """Test case for add_status

        Adds a new Status.  # noqa: E501
        """
        pass

    def test_add_statuses(self):
        """Test case for add_statuses

        Adds multiple statuses in one go.  # noqa: E501
        """
        pass

    def test_change_status(self):
        """Test case for change_status

        Changes the status with the information that is present in the request.  # noqa: E501
        """
        pass

    def test_change_statuses(self):
        """Test case for change_statuses

        Changes multiple statuses in one go.  # noqa: E501
        """
        pass

    def test_find_statuses(self):
        """Test case for find_statuses

        Returns statuses matching the given search criteria.  # noqa: E501
        """
        pass

    def test_get_status(self):
        """Test case for get_status

        Returns the Status identified by the given id.  # noqa: E501
        """
        pass

    def test_get_status_by_name(self):
        """Test case for get_status_by_name

        Returns the Status identified by the given name.  # noqa: E501
        """
        pass

    def test_remove_status(self):
        """Test case for remove_status

        Removes the Status identified by the given id.  # noqa: E501
        """
        pass

    def test_remove_statuses(self):
        """Test case for remove_statuses

        Removes multiple statuses.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
